@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.namedfile.testing import PLONE_NAMEDFILE_FUNCTIONAL_TESTING
 from plone.testing import layered
 
@@ -7,10 +6,10 @@ import unittest
 
 
 TEST_FILES = [
-    'usage.rst',
-    'handler.rst',
-    'marshaler.rst',
-    'utils.rst',
+    "usage.rst",
+    "handler.rst",
+    "marshaler.rst",
+    "utils.rst",
 ]
 
 
@@ -20,14 +19,11 @@ def test_suite():
             layered(
                 doctest.DocFileSuite(
                     testfile,
-                    package='plone.namedfile',
+                    package="plone.namedfile",
+                    optionflags=doctest.ELLIPSIS,
                 ),
-                PLONE_NAMEDFILE_FUNCTIONAL_TESTING
-            ) for testfile in TEST_FILES
+                PLONE_NAMEDFILE_FUNCTIONAL_TESTING,
+            )
+            for testfile in TEST_FILES
         ]
-
     )
-
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
